summaryrefslogtreecommitdiff
path: root/include/channels.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/channels.h')
-rw-r--r--include/channels.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/channels.h b/include/channels.h
index dda53f69d..3a6b38640 100644
--- a/include/channels.h
+++ b/include/channels.h
@@ -222,14 +222,14 @@ class CoreExport Channel : public Extensible, public InviteBase
/* Join a user to a channel. May be a channel that doesnt exist yet.
* @param user The user to join to the channel.
* @param cn The channel name to join to. Does not have to exist.
* @param key The key of the channel, if given
* @param override If true, override all join restrictions such as +bkil
* @return A pointer to the Channel the user was joined to. A new Channel may have
* been created if the channel did not exist before the user was joined to it.
* If the user could not be joined to a channel, the return value may be NULL.
*/
- static Channel* JoinUser(User *user, const char* cn, bool override, const char* key, bool bursting, time_t TS = 0);
+ static Channel* JoinUser(User *user, std::string channame, bool override, const std::string& key, bool bursting, time_t TS = 0);
/** Write to a channel, from a user, using va_args for text
* @param user User whos details to prefix the line with
@@ -222,14 +222,14 @@ class CoreExport Channel : public Extensible, public InviteBase
/* Join a user to a channel. May be a channel that doesnt exist yet.
* @param user The user to join to the channel.
- * @param cn The channel name to join to. Does not have to exist.
+ * @param channame The channel name to join to. Does not have to exist.
* @param key The key of the channel, if given
* @param override If true, override all join restrictions such as +bkil